@@ -2,15 +2,14 @@ from enum import Enum
 from typing import List
 
 import attr
-from deploy_tools.deploy import TransactionFailed
+from deploy_tools.transact import TransactionFailed
 from tldeploy.identity import (
     Delegate as DelegateImplementation,
+    ImplementationAddressNotFound,
     MetaTransaction,
     UnexpectedIdentityContractException,
     deploy_proxied_identity,
-    get_pinned_proxy_interface,
 )
-from web3.exceptions import BadFunctionCallOutput
 
 ZERO_ADDRESS = "0x" + "0" * 40
 
@@ -90,13 +89,9 @@ class Delegate:
             raise InvalidIdentityContractException
 
     def get_implementation_address(self, identity_address: str):
-        proxy_abi = get_pinned_proxy_interface()["abi"]
-        proxy_contract = self._web3.eth.contract(
-            abi=proxy_abi, address=identity_address
-        )
         try:
-            return proxy_contract.functions.implementation().call()
-        except BadFunctionCallOutput:
+            return self.delegate.get_implementation_address(identity_address)
+        except ImplementationAddressNotFound:
             raise InvalidIdentityContractException
 
     def calculate_fees_for_meta_transaction(
